vitamin a: info: https://en.wikipedia.org/wiki/Vitamin_A WHO: https://www.whocc.no/atc_ddd_index/?code=A11CA01 NIH: https://ods.od.nih.gov/factsheets/VitaminA-HealthProfessional/ USDA: per 100g: https://fdc.nal.usda.gov/fdc-app.html#/?component=1106 probable eventual mass: RAE, retinol activity equivalent https://www.dietarysupplementdatabase.usda.nih.gov/Conversions.php RAE is how much retinol the body produces (on average) with each of the equivalents. Vitamin A1 == Retinol Vitamin A https://ods.od.nih.gov/factsheets/VitaminA-HealthProfessional/ 1 IU retinol = 0.3 mcg RAE 1 IU supplemental beta-carotene = 0.3 mcg RAE 1 IU dietary beta-carotene = 0.05 mcg RAE 1 IU dietary alpha-carotene or beta-cryptoxanthin = 0.025 mcg RAE 1 mcg RAE == either ( 1 mcg retinol, 2 mcg supplemental beta-carotene, 12 mcg dietary beta-carotene, or 24 mcg dietary alpha-carotene or beta-cryptoxanthin ) references: https://pubmed.ncbi.nlm.nih.gov/32367133/ https://www.ncbi.nlm.nih.gov/pmc/articles/PMC7373782/ { "names": [ "vitamin a" ] "unites": [ "retinol", "retinal", "retinoic acid" ], "unites probable eventualities": [ ] } https://en.wikipedia.org/wiki/Retinoic_acid